UserTaskCreatedEvent class
- Inheritance
-
- Implemented types
-
Properties
-
accountId
↔ String?
-
Property getter and setter for accountId:
getter/setter pairinherited
-
contactId
↔ RecordKey?
-
Property getter and setter for contactId:
getter/setter pairoverride
-
dateCreated
↔ DateTime?
-
Property getter and setter for dateCreated:
getter/setter pairinherited
-
diffHashCode
→ int
-
no setterinherited
-
diffKey
→ dynamic
-
For
Diffable
no setterinherited
-
diffSource
→ dynamic
-
For
Diffable
no setterinherited
-
entityType
↔ MSchemaRef?
-
Property getter and setter for entityType:
getter/setter pairinherited
-
eventId
↔ String?
-
Property getter and setter for eventId:
getter/setter pairinherited
-
frameId
↔ RecordKey?
-
Property getter and setter for frameId:
getter/setter pairoverride
-
graphId
↔ String?
-
Property getter and setter for graphId:
getter/setter pairoverride
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String?
-
no setterinherited
-
ignoredPaths
→ Set<JsonPath>
-
no setterinherited
-
mfields
→ Set<String>
-
no setteroverride
-
mkey
→ MKey?
-
no setterinherited
-
mkeyOrNull
→ MKey?
-
no setterinherited
-
mtype
→ MSchemaRef
-
no setterinherited
-
nodeId
↔ String?
-
Property getter and setter for nodeId:
getter/setter pairoverride
-
recordKey
↔ RecordKey?
-
getter/setter pairinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
taskDescription
↔ String?
-
Property getter and setter for taskDescription:
getter/setter pairoverride
-
taskTitle
↔ String?
-
Property getter and setter for taskTitle:
getter/setter pairoverride
-
threadId
↔ RecordKey?
-
Property getter and setter for threadId:
getter/setter pairoverride
-
wrapped
→ Map<String, dynamic>
-
finalinherited
Methods
-
call<T>(dynamic key)
→ T?
-
inherited
-
clone()
→ UserTaskCreatedEvent
-
override
-
diffEquals(dynamic other)
→ bool
-
inherited
-
diffIdentical(dynamic other)
→ bool
-
inherited
-
get(String name)
→ dynamic
-
inherited
-
getByPath<T>(JsonPath path)
→ T
-
inherited
-
has(String fieldName)
→ bool
-
inherited
-
jpath<T>(JsonPath<T> path, [T? value])
→ T?
-
inherited
-
modified()
→ dynamic
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
prune(Set<String> fields)
→ void
-
inherited
-
setByPath<T>(JsonPath<T> path, T? value)
→ dynamic
-
inherited
-
sync([Set<String>? fields])
→ void
-
There are some weird cases where collections aren't synced properly with the underlying json. This will
overwrite the json with the latest value of the variable.
inherited
-
takeFrom(dynamic source)
→ void
-
override
-
takeFromMap(Map<String, dynamic>? from, {bool copyEntries = true})
→ void
-
Used for meta-forms in setting deep properties
override
-
toJson()
→ dynamic
-
override
-
toMap()
→ Map<String, dynamic>
-
For RouteParams - move at some point?
inherited
-
toString()
→ String
-
A string representation of this object.
override
Static Methods
-
fromJson(dynamic wrapped)
→ UserTaskCreatedEvent
-
override
-
of({required String? accountId, required String? eventId, required MSchemaRef? entityType, required RecordKey? recordKey, required DateTime? dateCreated, RecordKey? threadId, RecordKey? frameId, String? nodeId, String? graphId, String? taskTitle, String? taskDescription, RecordKey? contactId})
→ UserTaskCreatedEvent
-
override